pub enum ConstHandling {
Initializers,
Values,
}Expand description
How to handle constants and statics.
Variants
Initializers
Keep consts as calls to their initializer with ConstantExprKind::Call, without attempting
to do any const-evaluation. This is the default.
Values
Try evaluating consts and statics to their final value. If evaluation fails, we fall back to the initializer call.