pub enum StartFrom {
Pattern(NamePattern),
Attribute(String),
Pub,
}Expand description
Predicates that determine wihch items to use as starting point for translation.
Variants
Pattern(NamePattern)
Item identified by a pattern/path.
Attribute(String)
Item annotated with the given attribute.
Pub
Item marked pub. Note that this does not take accessibility into account; a
non-reexported pub item will be included here.
Implementations
Sourceimpl StartFrom
impl StartFrom
pub fn as_pattern(&self) -> Option<&NamePattern>
pub fn as_attribute(&self) -> Option<&String>
pub fn as_pub(&self) -> Option<()>
Sourceimpl StartFrom
impl StartFrom
pub fn as_pattern_mut(&mut self) -> Option<&mut NamePattern>
pub fn as_attribute_mut(&mut self) -> Option<&mut String>
pub fn as_pub_mut(&mut self) -> Option<()>